@@ -11,16 +11,16 @@
 import sys
 
 
-def ConductanceInSeries(g_list):
+def InSeries(g_list):
     sumOfInverse = sum([1/g for g in g_list])
     return 1/sumOfInverse
 
-def ConductanceInParallel(g_list):
+def InParallel(g_list):
     return sum(g_list)
 
 
-#Callable function for the module
+#callable function for the module
 class MyModule(sys.modules[__name__].__class__):
-    def __call__(self): #conductance
-        return 42 
+    def __call__(self, r): #conductance
+        return 1/r 
 sys.modules[__name__].__class__ = MyModule
\ No newline at end of file
